==> haskell-wai-logger-2.3.5-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.5
id: wai-logger-2.3.5-7cINmBOtDZcFx9boGarHiP
key: wai-logger-2.3.5-7cINmBOtDZcFx9boGarHiP
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
abi: c9829c13602b6b569a97e31ce8e69fc0
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-logger-2.3.5
hs-libraries: HSwai-logger-2.3.5-7cINmBOtDZcFx9boGarHiP
depends:
    base-4.12.0.0 byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw
    bytestring-0.10.8.2 fast-logger-2.4.16-BphF1Z6pLYZ9rJKH5Zk5dn
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.3.5-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.5
id: wai-logger-2.3.5-4ExE5c8bXTx5FDa83fvTPz
key: wai-logger-2.3.5-4ExE5c8bXTx5FDa83fvTPz
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
abi: fd483d7774746e99ab9d28fb7c21c637
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-logger-2.3.5
hs-libraries: HSwai-logger-2.3.5-4ExE5c8bXTx5FDa83fvTPz
depends:
    base-4.12.0.0 byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw
    bytestring-0.10.8.2 fast-logger-2.4.17-EIkTgShDAYOFSHXqB4KinN
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
